Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(728)

Unified Diff: chrome/browser/download/download_core_service.h

Issue 2853363002: Rename the DownloadService to DownloadCoreService (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/download/download_core_service.h
diff --git a/chrome/browser/download/download_service.h b/chrome/browser/download/download_core_service.h
similarity index 82%
rename from chrome/browser/download/download_service.h
rename to chrome/browser/download/download_core_service.h
index 186251814bd90cccc6b6fb7a5d4516da272cf8e0..af9c2759544c6d02c6cf39a3dcf1f663b19c2630 100644
--- a/chrome/browser/download/download_service.h
+++ b/chrome/browser/download/download_core_service.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_DOWNLOAD_DOWNLOAD_SERVICE_H_
-#define CHROME_BROWSER_DOWNLOAD_DOWNLOAD_SERVICE_H_
+#ifndef CHROME_BROWSER_DOWNLOAD_DOWNLOAD_CORE_SERVICE_H_
+#define CHROME_BROWSER_DOWNLOAD_DOWNLOAD_CORE_SERVICE_H_
#include <memory>
@@ -23,12 +23,12 @@ namespace extensions {
class ExtensionDownloadsEventRouter;
}
-// Abstract base class for the download service; see DownloadServiceImpl for
-// implementation.
-class DownloadService : public KeyedService {
+// Abstract base class for the download core service; see
+// DownloadCoreServiceImpl for implementation.
+class DownloadCoreService : public KeyedService {
public:
- DownloadService();
- ~DownloadService() override;
+ DownloadCoreService();
+ ~DownloadCoreService() override;
// Get the download manager delegate, creating it if it doesn't already exist.
virtual ChromeDownloadManagerDelegate* GetDownloadManagerDelegate() = 0;
@@ -70,7 +70,7 @@ class DownloadService : public KeyedService {
virtual bool IsShelfEnabled() = 0;
private:
- DISALLOW_COPY_AND_ASSIGN(DownloadService);
+ DISALLOW_COPY_AND_ASSIGN(DownloadCoreService);
};
-#endif // CHROME_BROWSER_DOWNLOAD_DOWNLOAD_SERVICE_H_
+#endif // CHROME_BROWSER_DOWNLOAD_DOWNLOAD_CORE_SERVICE_H_

Powered by Google App Engine
This is Rietveld 408576698